==> huaweicloudsdkworkspaceapp-3.1.131-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/batch_change_maintain_server_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchChangeMaintainServerReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'items': 'list[str]',
        'maintain_status': 'bool'
    }

    attribute_map = {
        'items': 'items',
        'maintain_status': 'maintain_status'
    }

    def __init__(self, items=None, maintain_status=None):
        """BatchChangeMaintainServerReq

        The model defined in huaweicloud sdk

        :param items: 批量请求的服务器ID列表，一次请求数量区间 [1, 20]。
        :type items: list[str]
        :param maintain_status: 服务器维护状态标识： * &#x60;true&#x60; - 添加标记 * &#x60;false&#x60; - 移除标记
        :type maintain_status: bool
        """
        
        

        self._items = None
        self._maintain_status = None
        self.discriminator = None

        self.items = items
        self.maintain_status = maintain_status

    @property
    def items(self):
        """Gets the items of this BatchChangeMaintainServerReq.

        批量请求的服务器ID列表，一次请求数量区间 [1, 20]。

        :return: The items of this BatchChangeMaintainServerReq.
        :rtype: list[str]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this BatchChangeMaintainServerReq.

        批量请求的服务器ID列表，一次请求数量区间 [1, 20]。

        :param items: The items of this BatchChangeMaintainServerReq.
        :type items: list[str]
        """
        self._items = items

    @property
    def maintain_status(self):
        """Gets the maintain_status of this BatchChangeMaintainServerReq.

        服务器维护状态标识： * `true` - 添加标记 * `false` - 移除标记

        :return: The maintain_status of this BatchChangeMaintainServerReq.
        :rtype: bool
        """
        return self._maintain_status

    @maintain_status.setter
    def maintain_status(self, maintain_status):
        """Sets the maintain_status of this BatchChangeMaintainServerReq.

        服务器维护状态标识： * `true` - 添加标记 * `false` - 移除标记

        :param maintain_status: The maintain_status of this BatchChangeMaintainServerReq.
        :type maintain_status: bool
        """
        self._maintain_status = maintain_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchChangeMaintainServerReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.156-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/batch_change_maintain_server_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchChangeMaintainServerReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'items': 'list[str]',
        'maintain_status': 'bool'
    }

    attribute_map = {
        'items': 'items',
        'maintain_status': 'maintain_status'
    }

    def __init__(self, items=None, maintain_status=None):
        r"""BatchChangeMaintainServerReq

        The model defined in huaweicloud sdk

        :param items: 批量请求的服务器ID列表，一次请求数量区间 [1, 20]。
        :type items: list[str]
        :param maintain_status: 服务器维护状态标识： * &#x60;true&#x60; - 添加标记 * &#x60;false&#x60; - 移除标记
        :type maintain_status: bool
        """
        
        

        self._items = None
        self._maintain_status = None
        self.discriminator = None

        self.items = items
        self.maintain_status = maintain_status

    @property
    def items(self):
        r"""Gets the items of this BatchChangeMaintainServerReq.

        批量请求的服务器ID列表，一次请求数量区间 [1, 20]。

        :return: The items of this BatchChangeMaintainServerReq.
        :rtype: list[str]
        """
        return self._items

    @items.setter
    def items(self, items):
        r"""Sets the items of this BatchChangeMaintainServerReq.

        批量请求的服务器ID列表，一次请求数量区间 [1, 20]。

        :param items: The items of this BatchChangeMaintainServerReq.
        :type items: list[str]
        """
        self._items = items

    @property
    def maintain_status(self):
        r"""Gets the maintain_status of this BatchChangeMaintainServerReq.

        服务器维护状态标识： * `true` - 添加标记 * `false` - 移除标记

        :return: The maintain_status of this BatchChangeMaintainServerReq.
        :rtype: bool
        """
        return self._maintain_status

    @maintain_status.setter
    def maintain_status(self, maintain_status):
        r"""Sets the maintain_status of this BatchChangeMaintainServerReq.

        服务器维护状态标识： * `true` - 添加标记 * `false` - 移除标记

        :param maintain_status: The maintain_status of this BatchChangeMaintainServerReq.
        :type maintain_status: bool
        """
        self._maintain_status = maintain_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchChangeMaintainServerReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
